package VMOMI::DatastoreSummaryMaintenanceModeState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
